OC.L10N.register(
    "spreed",
    {
    "(Duration %s)" : "(kestus %s)",
    "You attended a call with {user1}" : "Sa osalesid kõnes kasutajaga {user1}",
    "_%n guest_::_%n guests_" : ["%n külaline","%n külalist"],
    "You attended a call with {user1} and {user2}" : "Sa osalesid kõnes kasutajatega {user1} ja {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Sa osalesid kõnes kasutajatega {user1}, {user2} ja {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Sa osalesid kõnes kasutajatega {user1}, {user2}, {user3} ja {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Sa osalesid kõnes kasutajatega {user1}, {user2}, {user3}, {user4} ja {user5}",
    "_%n other_::_%n others_" : ["%n muu","%n muud"],
    "{actor} invited you to {call}" : "{actor} kutsus sind osalema „{call}“ kõnes ",
    "Other activities" : "Muud tegevused",
    "Talk" : "Talk",
    "Guest" : "Külaline",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Vestlustel on nüüd ooteruum. See võimaldab moderaatoritel liituda ettevalmistamiseks vestluse või kõnega ning muud osalejad ja külalised asuvad seni ooteruumis,",
    "You created the conversation" : "Sina lõid selle vestluse",
    "{actor} removed the description" : "{actor} eemaldas kirjelduse",
    "You removed the description" : "Sina eemaldasid kirjelduse",
    "An administrator removed the description" : "Peakasutaja eemaldas kirjelduse",
    "Outgoing silent call" : "Väljuv vaikne kõne",
    "Incoming silent call" : "Sissetulev vaikne kõne",
    "Outgoing call" : "Väljuv kõne",
    "Incoming call" : "Sissetulev kõne",
    "{actor} removed the password" : "{actor} eemaldas salasõna",
    "You removed the password" : "Sina eemaldasid salasõna",
    "An administrator removed the password" : "Peakasutaja eemaldas salasõna",
    "You added {user}" : "Sina lisasid kasutaja {user}",
    "{actor} added you" : "{actor} lisas sinu",
    "An administrator added you" : "Peakasutaja lisas sinu",
    "{actor} removed {user}" : "{actor} eemaldas kasutaja {user}",
    "You removed {user}" : "Sina eemaldasid kasutaja {user}",
    "{actor} removed you" : "{actor} eemaldas sinu",
    "An administrator removed you" : "Peakasutaja eemaldas sinu",
    "An administrator removed {user}" : "Peakasutaja eemaldas kasutaja {user}",
    "{actor} removed {federated_user}" : "{actor} eemaldas kasutaja {federated_user}",
    "You removed {federated_user}" : "Sina eemaldasid kasutaja {federated_user}",
    "An administrator removed {federated_user}" : "Peakasutaja eemaldas kasutaja {federated_user}",
    "{actor} added group {group}" : "{actor} lisas „{group}“ grupi",
    "You added group {group}" : "Sina lisasid „{group}“ grupi",
    "An administrator added group {group}" : "Peakasutaja lisas „{group}“ grupi",
    "{actor} removed group {group}" : "{actor} eemaldas „{group}“ grupi",
    "You removed group {group}" : "Sina eemaldasid „{group}“ grupi",
    "An administrator removed group {group}" : "Peakasutaja eemaldas „{group}“ grupi",
    "{actor} added team {circle}" : "{actor} lisas „{circle}“ tiimi",
    "You added team {circle}" : "Sina lisasid „{circle}“ tiimi",
    "An administrator added team {circle}" : "Peakasutaja lisas „{circle}“ tiimi",
    "{actor} removed team {circle}" : "{actor} eemaldas tiimi „{circle}“",
    "You removed team {circle}" : "Sina eemaldasid „{circle}“ tiimi",
    "An administrator removed team {circle}" : "Peakasutaja eemaldas „{circle}“ tiimi",
    "You added {phone}" : "Sina lisasid telefoni „{phone}“",
    "{actor} removed {phone}" : "{actor} eemaldas  {phone}",
    "You removed {phone}" : "Sina eemaldasid {phone}",
    "An administrator removed {phone}" : "Peakasutaja eemaldas  {phone}",
    "{actor} promoted {user} to moderator" : "{actor} määras kasutaja {user} moderaatoriks",
    "You promoted {user} to moderator" : "Sina määrasid kasutaja {user} moderaatoriks",
    "{actor} promoted you to moderator" : "{actor} määras sinu moderaatoriks",
    "An administrator promoted you to moderator" : "Peakasutaja määras sinu moderaatoriks",
    "An administrator promoted {user} to moderator" : "Peakasutaja määras kasutaja {user} moderaatoriks",
    "{actor} removed the Matterbridge configuration" : "{actor} eemaldas Matterbridge'i võrgusilla seadistused",
    "You removed the Matterbridge configuration" : "Sina eemaldasid Matterbridge'i võrgusilla seadistused",
    "{actor} edited a message" : "{actor} muutis sõnumit",
    "You edited a message" : "Sina muutsid sõnumit",
    "{actor} removed the conversation picture" : "{actor} eemaldas vestluse pildi",
    "You removed the conversation picture" : "Sina eemaldasid vestluse pildi",
    "Message deleted by author" : "Sõnum autori poolt kustutatud",
    "Message deleted by you" : "Sina kustutasid sõnumi",
    "Administration" : "Haldus",
    "System" : "Süsteem",
    "%s (guest)" : "%s (külaline)",
    "Missed call" : "Märkamata kõne",
    "Unanswered call" : "Vastamata kõne",
    "Talk to %s" : "Suhtle: %s",
    "File is too big" : "Fail on liiga suur",
    "Invalid file provided" : "Vigane fail",
    "Invalid image" : "Vigane pilt",
    "Unknown filetype" : "Tundmatu failitüüp",
    "%1$s invited you to conversation \"%2$s\"." : "%1$s kutsus sind „%2$s“ vestlusesse.",
    "You were invited to conversation \"%s.\"" : "Sa said kutse „%s“ vestlusesse.",
    "Scheduled time" : "Plaanitud aeg",
    "Description" : "Kirjeldus",
    "Click the button below to join the lobby now." : "Ooteruumiga liitumiseks vajuta allolevat nuppu.",
    "Click the link below to join the lobby now." : "Ooteruumiga liitumiseks vajuta allolevat linki.",
    "Join lobby for \"%s\"" : "Sisene „%s“ ooteruumi",
    "Click the button below to join the conversation now." : "Vestlusega liitumiseks vajuta allolevat nuppu.",
    "Click the link below to join the conversation now." : "Vestlusega liitumiseks vajuta allolevat linki.",
    "Join \"%s\"" : "Liitu: „%s“",
    "Dismiss notification" : "Sulge teavitus",
    "Accept" : "Nõustu",
    "Decline" : "Keeldu",
    "{user} mentioned team {team} in conversation {call}" : "{user} mainis „{team}“ tiimi „{call}“ vestluses",
    "A deleted user mentioned team {team} in conversation {call}" : "Kustutatud kasutaja mainis „{team}“ tiimi „{call}“ vestluses",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "„{guest}“ (külaline) mainis „{call}“ vestluses „{team}“ tiimi",
    "A guest mentioned team {team} in conversation {call}" : "Külaline mainis „{call}“ vestluses „{team}“ tiimi",
    "Join call" : "Liitu kõnega",
    "You missed a call from {user}" : "Vastamata kõne kasutajalt {user}",
    "You missed a group call in {call}" : "Vastamata kõne grupis {call}",
    "error" : "viga",
    "Conversations" : "Vestlused",
    "Messages" : "Sõnumid",
    "Avatar image is not square" : "Avatari pilt pole ruut",
    "Note to self" : "Minu märkmed",
    "Let's get started!" : "Alustame!",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in a the conversation %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭 Lase vestlusel kulgeda: maini kasutajaid, reageeri sõnumitele ja palju muud\n\n„%s“ vestluses saadi mainida kõiki või ühte konkreetset osaleja, selleks sisesta „@“ vali loendist soovitud nimi.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "Sa võid sõnumitele vastata, neid teistesse vestlustesse või teistele kasutajatele edastada ning kopeerida sõnumite sisu.",
    "Denmark" : "Taani",
    "Federation" : "Liidendus",
    "High-performance backend not configured correctly" : "Suure jõudlusega taustateenus pole korrektselt seadistatud",
    "Error: Certificate expired" : "Viga: sertifikaat on aegunud",
    "Error: Server responded with: {error}" : "Viga: serveri vastuseks on {error}",
    "Error: Unknown error occurred" : "Viga: tekkis tundmatu viga",
    "Client Push" : "Tõuketeenused kliendile",
    "Client Push is installed, this improves the performance of desktop clients." : "Tõuketeenused kliendile on paigaldatud ja see parandab töölauaklientide jõudlust.",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push} pole paigaldatud ja see võib töölauaklientide puhul tekitada jõudlusprobleeme.",
    "SIP configuration" : "SIP-i seadistused",
    "Using the SIP functionality requires a High-performance backend." : "SIP-i funktsionaalsuse kasutamine eeldab serveris suure jõudlusega taustateenuse olemasolu.",
    "No SIP backend configured" : "Ühtegi SIP-i taustateenust pole seadistatud",
    "Invalid date, date format must be YYYY-MM-DD" : "Vigane kuupäev, vorming peab olema YYYY-MM-DD",
    "Conversation not found" : "Vestlust ei leidu",
    "Path is already shared with this conversation" : "Asukoht on selle vestlusega juba jagatud",
    "Leave call" : "Lahku kõnest",
    "Everyone" : "Igaüks",
    "Save changes" : "Salvesta muudatused",
    "Saving …" : "Salvestamine …",
    "Saved!" : "Salvestatud!",
    "Limit to groups" : "Luba gruppidele",
    "Enabled" : "Sisse lülitatud",
    "Disabled" : "Keelatud",
    "State" : "Olek",
    "Name" : "Nimi",
    "Permissions" : "Õigused",
    "Off" : "Pole kasutusel",
    "End-to-end encrypted calls" : "Läbivalt krüptitud kõned",
    "Enable encryption" : "Luba krüptimine",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "Seadistatud SIP-i võrgusilla vahendusel tehtavad läbivalt krüptitud kõned eeldavad uuema suure jõudlusega taustateenuse ja SIP-i võrgusilla kasutamist.",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "Nutiseadmete kliendid hetkel ei toeta läbivalt krüptitud kõnesid",
    "Pending" : "Ootel",
    "Error" : "Viga",
    "Blocked" : "Blokeeritud",
    "Active" : "Aktiivne",
    "Expired" : "Aegunud",
    "Email of the user" : "Kasutaja e-posti aadress",
    "Language" : "Keel",
    "Country" : "Riik",
    "Request signaling server trial" : "Taotle testperioodi kõnehõlbustusserveris",
    "You can see the current status of your hosted signaling server in the following table." : "Järgnevas tabelis näed oma kõnehõlbustusserveri praegust olekut.",
    "Status" : "Staatus",
    "Created at" : "Loodud",
    "Expires at" : "Aegub",
    "Limits" : "Piirangud",
    "Delete the signaling server account" : "Kustuta kasutajakonto kõnehõlbustusserveris",
    "_%n user_::_%n users_" : ["%n kasutaja","%n kasutajat"],
    "Installed version: {version}" : "Paigaldatud versioon: {version}",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "Matterbridge'i käivitusfauilil on vigased õigused. Palun kontrolli, et Matterbridge'i käivitusfaili omanik on korrektne ja ta saab seda käivitada. Leiad ta siit: „/…/nextcloud/apps/talk_matterbridge/bin/“.",
    "Downloading …" : "Laadin alla…",
    "Error: Server seems to be a Signaling server" : "Viga: server tundub olema kõnehõlbustusserver",
    "Delete this server" : "Kustuta see server",
    "Nextcloud portal" : "Nextcloudi portaal",
    "Quick installation guide" : "Paigalduse kiirjuhend",
    "Failed" : "Ebaõnnestus",
    "OK" : "OK",
    "Federated user" : "Kasutaja liitpilves",
    "Confirm" : "Kinnita",
    "Reset" : "Lähtesta",
    "Back" : "Tagasi",
    "Cancel" : "Loobu",
    "Now" : "Praegu",
    "Invalid calendar selected" : "Valisid vale kalendri",
    "Invalid start time selected" : "Valisid vale algusaja",
    "Invalid end time selected" : "Valisid vale lõpuaja",
    "Unknown error occurred" : "Tekkis tundmatu viga",
    "{participant0} will receive an invitation" : "{participant0} saab kutse",
    "{participant0} and {participant1} will receive invitations" : "{participant0} ja {participant1} saavad kutse",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}, {participant1} ja %n muu kasutaja saavad kutse","{participant0}, {participant1} ja %n muud kasutajat saavad kutse"],
    "Invite {user}" : "Saada kutse kasutajale {user}",
    "Invite all users and emails in this conversation" : "Saada kutse kõikidele selle vestluse kasutajatele ja e-posti aadressidele",
    "Meeting created" : "Kohtumine on loodud",
    "Upcoming meetings" : "Tulekul kohtumised",
    "Next meeting" : "Järgmine kohtumine",
    "Loading …" : "Laadimine ...",
    "No upcoming events" : "Tulekul sündmuseid pole",
    "Schedule a meeting" : "Ajasta kohtumine",
    "Meeting title" : "Kohtumise nimi",
    "From" : "Saatja",
    "To" : "Saaja",
    "Calendar" : "Kalender",
    "Attendees" : "Osalejad",
    "No other participants to send invitations to." : "Pole ühtegi teist osalejat, kellele kutset saata.",
    "Add attendees" : "Lisa osalejaid",
    "Save" : "Salvesta",
    "Search participants" : "Otsi osalejaid",
    "No results" : "Vasteid ei leitud",
    "Done" : "Valmis",
    "Lobby is still active and you're not a moderator" : "Ooteruum on jätkuvalt kasutusel ja sina pole moderaator",
    "A participant raised their hand." : "Üks osaleja andis käega märku",
    "Copy link" : "Kopeeri link",
    "You" : "Sina",
    "Collapse" : "Sulge",
    "Public conversation" : "Avalik vestlus",
    "Favorite" : "Lemmik",
    "Date:" : "Kuupäev:",
    "Note:" : "Märkus:",
    "Hide details" : "Peida üksikasjad",
    "Show details" : "Näita üksikasju",
    "Unban" : "Eemalda suhtluskeeld",
    "Edit conversation name" : "Muuda vestluse nime",
    "Edit conversation description" : "Muuda vestluse kirjeldust",
    "Disable" : "Lülita välja",
    "Enable" : "Lülita sisse",
    "Choose" : "Vali",
    "Remove conversation picture" : "Eemalda vestluse pilt",
    "The file must be a PNG or JPG" : "Fail peab olema png või jpg vormingus",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Muuda kasutajate vaikimisi õigusi siin vestluses. See ei mõjuuta moderaatorite õigusi.",
    "Restricted" : "Piiratud",
    "Advanced permissions" : "Täiendavad õigused",
    "Edit permissions" : "Muuda õigusi",
    "Conversation settings" : "Vestluse seadistused",
    "Basic Info" : "Põhiteave",
    "Personal" : "Isiklik",
    "Moderation" : "Modereerimine",
    "Setup overview" : "Seadistuse ülevaade",
    "Breakout Rooms" : "Eraldi jututoad",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Võrgurobotid",
    "Danger zone" : "Ohtlik - siin ole ettevaatlik",
    "Archive conversation" : "Arhiveeri vestlus",
    "Do you really want to leave \"{displayName}\"?" : "Kas sa kindlasti soovid „{displayName}“ jututoast lahkuda?",
    "Do you really want to delete \"{displayName}\"?" : "Kas sa kindlasti soovid „{displayName}“ jututoa kustutada?",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Kas sa kindlasti soovid „{displayName}“ jututoast kõik vestlused kustutada?",
    "You need to promote a new moderator before you can leave the conversation" : "Pead määrama uue moderaatori enne siit vestlusest lahkumist",
    "Error while deleting conversation" : "Viga vestluse kustutamisel",
    "Error while clearing chat history" : "Viga vestluse ajaloo kustutamisel",
    "Be careful, these actions cannot be undone." : "Palun ole ettevaatlik - neid tegevusi ei saa tagasi pöörata.",
    "Leave conversation" : "Lahku vestlusest",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Kui lahkud kinnisest vestlusest, siis vajad uuesti liitumiseks luba. Avatud vestlusega saad liituda omal äranägemisel.",
    "You can archive this conversation instead." : "Selle asemel võid antud vestluse arhiveerida.",
    "No" : "Ei",
    "Yes" : "Ja",
    "Delete conversation" : "Kustuta vestlus",
    "Permanently delete this conversation." : "Kustuta see vestlus jäädavalt.",
    "Delete chat messages" : "Kustuta vestluse sõnumid",
    "Permanently delete all the messages in this conversation." : "Kustuta jäädavalt kõik selle vestluse sõnumid.",
    "Delete all chat messages" : "Kustuta kõik vestluse sõnumid",
    "_%n hour_::_%n hours_" : ["%n tund","%n tundi"],
    "_%n day_::_%n days_" : ["%n päev","%n päeva"],
    "_%n week_::_%n weeks_" : ["%n nädal","%n nädalat"],
    "Custom expiration time" : "Sinu valitud aegumine",
    "Message expiration disabled" : "Sõnumi aegumine pole kasutusel",
    "Message expiration set: {duration}" : "Sõnum aegub: {duration}",
    "Error when trying to set message expiration" : "Viga sõnumi aegumise määramisel",
    "Message expiration" : "Sõnumi aegumine",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Vestluse sõnumid saad määrata kustuma etteantud aja järel. Palun arvesta, et sel juhul vestluses jagatud failid jäävad omaniku jaoks nähtavaks, aga pole enam vestluse jaoks jagatud.",
    "Set message expiration" : "Määra sõnumi aegumine",
    "Current message expiration" : "Sõnumi aegumine",
    "Password copied to clipboard" : "Salasõna on kopeeritud lõikelauale.",
    "Password could not be copied" : "Salasõna ei õnnestunud lõikelauale kopeerida.",
    "Password protection" : "Password protection",
    "Set a password" : "Lisa salasõna",
    "Enter new password" : "Sisesta uus salasõna",
    "Save password" : "Salvesta salasõna",
    "Copy password" : "Kopeeri salasõna",
    "Guests are allowed to join this conversation via link" : "Külalised võivad selle vestlusega lingi alusel liituda",
    "Guests are not allowed to join this conversation" : "Külalised ei või selle vestlusega liituda",
    "Resend invitations" : "Saada kutsed uuesti",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Ooteruumi sisselülitamine selle kõne jaoks eemaldab kõik tavakasutajad (i.e. kes pole moderaatorid) sellest pooleliolevast kõnest.",
    "Enable lobby, restricting the conversation to moderators" : "Lülita sisse ooteruum ja piira osalemine vaid moderaatoritega",
    "Lock conversation" : "Lukusta vestlus",
    "Edit" : "Muuda",
    "Delete" : "Kustuta",
    "Log content" : "Logi sisu",
    "Notifications" : "Teavitused",
    "Error while creating the conversation" : "Viga vestluse loomisel",
    "Start a group conversation" : "Alusta rühmavestlust",
    "Create conversation" : "Loo vestlus",
    "Enter your name" : "Sisesta oma nimi",
    "Log in" : "Logi sisse",
    "Search participants or phone numbers" : "Otsi osalejaid või telefoninumbreid",
    "Mark as read" : "Märgi loetuks",
    "Mark as unread" : "Märgi mitteloetuks",
    "Remove from favorites" : "Eemalda lemmikutest",
    "Add to favorites" : "Lisa lemmikutesse",
    "You need to promote a new moderator before you can leave the conversation." : "Pead määrama uue moderaatori enne siit vestlusest lahkumist.",
    "Unread" : "Lugemata",
    "Mentions" : "Mainimised",
    "An error occurred while performing the search" : "Otsimisel tekkis viga",
    "Create a new conversation" : "Loo uus vestlus",
    "Join open conversations" : "Liitu avalike vestlustega",
    "Clear filter" : "Tühjenda filter",
    "Unread mentions" : "Lugemata mainimised",
    "Users" : "Kasutajad",
    "Groups" : "Grupid",
    "Teams" : "Tiimid",
    "No search results" : "Otsingul pole tulemusi",
    "You are currently waiting in the lobby" : "Sa asud hetkel ooteruumis",
    "None" : "Pole",
    "Select speaker" : "Vali esineja",
    "No speaker available" : "Esinejat pole saadaval",
    "Select a device" : "Vali seade",
    "Devices" : "Seadmed",
    "Call without notification" : "Kõne ilma teavituseta",
    "Invalid path selected" : "Vigane asukoht on valitud",
    "Blur" : "Hägusus",
    "Upload" : "Laadi üles",
    "Files" : "Failid",
    "Select a file" : "Vali fail",
    "Message sent" : "Sõnum on saadetud",
    "Sent without notification" : "Saadetud ilma teavituseta",
    "Deleting message" : "Sõnum on kustutamisel",
    "Message deleted successfully" : "Sõnumi kustutamine õnnestus",
    "Unread messages" : "Lugemata sõnumid",
    "Set reminder for later today" : "Lisa meeldetuletus tänaseks hilisemaks ajaks",
    "Set reminder for tomorrow" : "Lisa meeldetuletus homseks",
    "Set reminder for this weekend" : "Lisa meeldetuletus selleks nädalavahetuseks",
    "Set reminder for next week" : "Lisa meeldetuletus järgmiseks nädalaks",
    "Edited by {actor}" : "{actor} muutis sõnumit",
    "Message text copied to clipboard" : "Sõnumi tekst on kopeeritud lõikelauale",
    "Message text could not be copied" : "Sõnumi teksti kopeerimine ei õnnestunud",
    "Message forwarded to \"Note to self\"" : "Sõnum on edastatud vestlusesse „Minu märkmed“",
    "Error while forwarding message to \"Note to self\"" : "Viga sõnumi edastatamisel vestlusesse „Minu märkmed“",
    "A reminder was successfully removed" : "Meeldetuletuse eemaldamine õnnestus",
    "Reply" : "Vasta",
    "Set reminder" : "Lisa meeldetuletus",
    "Reply privately" : "Vasta privaatselt",
    "Edit message" : "Muuda sõnumit",
    "Copy message" : "Kopeeri sõnum",
    "Copy message link" : "Kopeeri sõnumi link",
    "Download file" : "Laadi fail alla",
    "Translate" : "Tõlgi",
    "Set custom reminder" : "Lisa enda valitud meeldetuletus",
    "Dismiss" : "Jäta vahele",
    "The message could not be translated" : "E-kirja tõlkimine ei õnnestunud",
    "Translation copied to clipboard" : "Tõlge on kopeeritud lõikelauale",
    "Translation could not be copied" : "Tõlke kopeerimine ei õnnestunud",
    "Translate message" : "Tõlgi e-kiri",
    "Source language to translate from" : "Tõlke lähtekeel",
    "Translate from" : "Lähtekeel tõlkimisel",
    "Target language to translate into" : "Sihtkeel tõlkimisel",
    "Translate to" : "Tõlke sihtkeel",
    "Translating" : "Tõlkimisel",
    "Copy translated text" : "Kopeeri tõlgitud tekst",
    "Contact" : "Kontakt",
    "Remove {fileName}" : "Eemalda fail: „{fileName}“",
    "Sending message" : "Saadan sõnumit",
    "Copy code block" : "Kopeeri koodiplokk",
    "Edit poll draft" : "Muuda küsitluse kavandit",
    "Today" : "Täna",
    "Yesterday" : "Eile",
    "_%n day ago_::_%n days ago_" : ["%n päev tagasi","%n päeva tagasi"],
    "Create a new group conversation" : "Loo uus vestlusrühm",
    "Add participants" : "Lisa osalejaid",
    "Send message silently" : "Saada sõnum vaikselt",
    "Send message" : "Saada sõnum",
    "The message could not be edited" : "Sõnumi muutmine ei õnnestunud",
    "Add emoji" : "Lisa emoji",
    "Cancel editing" : "Katkesta muutmine",
    "Replacement:" : "Asendus:",
    "Share from Files" : "Jaga failirakendusest",
    "Upload from device" : "Laadi üles seadmest",
    "Create new poll" : "Loo uus küsitlus",
    "Record voice message" : "Salvesta häälsõnum",
    "Generating summary of unread messages …" : "Koostan lugemata sõnumite ülevaadet…",
    "New file" : "Uus fail",
    "Blank" : "Tühi",
    "Create and share a new file" : "Loo uus fail ning jaga teda",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} ja veel %n kasutaja kirjutavad…","{user1}, {user2}, {user3} ja veel %n kasutajat kirjutavad…"],
    "Send" : "Saada",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Muuda kasutajate vaikimisi õigusi vestluses <strong>{conversationName}</strong>",
    "Skip the lobby" : "Jäta ooteruum vahele",
    "Create poll in {name}" : "Loo siin küsitlus: {name}",
    "Create poll" : "Loo küsitlus",
    "Question" : "Küsimus",
    "Settings" : "Seaded",
    "Anonymous poll" : "Anonüümne küsitlus",
    "(editing)" : "(muutmisel)",
    "Send a message to \"{roomName}\"" : "Saada sõnum „{roomName}“ jututuppa",
    "Send message to room" : "Saada sõnum jututuppa",
    "Disable lobby" : "Lülita ooteruumi kasutamine välja",
    "guest" : "külaline",
    "Remove group and members" : "Eemalda gruppe ja liikmeid",
    "Remove team and members" : "Eemalda tiime ja liikmeid",
    "Remove participant" : "Eemalda osalejaid",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "Kas sa kindlasti soovid eemaldada „{displayName}“ grupi koos oma liikmetega sellest vestlusest?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "Kas sa kindlasti soovid eemaldada „{displayName}“ tiimi koos oma liikmetega sellest vestlusest?",
    "Do you really want to remove {displayName} from this conversation?" : "Kas sa kindlasti soovid eemaldada „{displayName}“ sellest vestlusest?",
    "Permissions granted to {displayName}" : "Õigused on antud kasutajale {displayName}",
    "Permissions removed for {displayName}" : "Õigused on eemaldatud kasutajalt {displayName}",
    "in the lobby" : "ooteruumis",
    "Move back to lobby" : "Suundu tagasi ooteruumi",
    "Promote to moderator" : "Määra moderaatoriks",
    "Copy phone number" : "Kopeeri telefoninumber",
    "Grant all permissions" : "Anna kõik õigused",
    "Remove all permissions" : "Eemalda kõik õigused",
    "Also ban from this conversation" : "Samaga sea suhtluskeeld siin vestluses",
    "Internal note (reason to ban)" : "Sisemine märge (suhtluskeelu põhjus)",
    "Remove" : "Eemalda",
    "Add users, groups or teams" : "Lisa kasutajaid, gruppe või tiime",
    "Add users or groups" : "Lisa kasutajaid või gruppe",
    "Add users or teams" : "Lisa kasutajaid või tiime",
    "Add users" : "Lisa kasutajaid",
    "Add groups or teams" : "Lisa gruppe või tiime",
    "Add groups" : "Lisa gruppe",
    "Add teams" : "Lisa tiime",
    "Searching …" : "Otsin ...",
    "Search for more users" : "Otsi veel kasutajaid",
    "Search or add participants" : "Otsi või lisa osalejaid",
    "A new group conversation with selected participant will be created" : "Järgnevaga luuakse valitud osalejaga uus rühmavestlus",
    "Participants" : "Osalejad",
    "Participants ({count})" : "Osalejad ({count})",
    "Open chat" : "Ava vestlus",
    "Search in {name}" : "Otsi siin: {name}",
    "Search messages" : "Otsi sõnumeid",
    "Details" : "Üksikasjad",
    "Search messages …" : "Otsi sõnumeid…",
    "Search options" : "Otsinguvalikud",
    "From User" : "Kasutajalt",
    "Since" : "Alates",
    "Until" : "Kuni",
    "No results found" : "Otsingutulemusi ei leidu",
    "Load more results" : "Laadi veel tulemusi",
    "Projects" : "Projektid",
    "Select conversation" : "Vali vestlus",
    "Edit display name" : "Muuda kuvatavat nime",
    "Your personal setting has been saved" : "Sinu isiklik seadistus on salvestatud",
    "Error while setting personal setting" : "Viga isikliku seadistuste salvestamisel",
    "Appearance" : "Välimus",
    "Show conversations list in compact mode" : "Näita vestluste loendit kompaktses vaates",
    "Privacy" : "Privaatsus",
    "Keyboard shortcuts" : "Klaviatuuri otseteed",
    "Edit your last message" : "Muuda oma viimast sõnumit",
    "Search" : "Otsi",
    "Shortcuts while in a call" : "Kiirklahvid kõne ajal",
    "Camera on and off" : "Kaamera sisse/välja",
    "Microphone on and off" : "Mikrofon sisse/välja",
    "Space bar" : "Tühikuklahv",
    "Push to talk or push to mute" : "Vajuta rääkimiseks või summutamiseks",
    "Raise or lower hand" : "Anna käega märku või lõpeta märguandmine",
    "Mouse wheel" : "Hiire ratas",
    "Zoom-in / zoom-out a screen share" : "Suumi jagatavas ekraanis sisse/välja",
    "Start call silently" : "Helista vaikselt",
    "Start call" : "Helista",
    "End call" : "Lõpeta kõne",
    "End call for everyone" : "Lõpeta kõne kõigi jaoks",
    "The call has been running for one hour." : "Kõne on kestnud üle tunni.",
    "Add participants to this call" : "Lisa sellele kõnele osalejaid",
    "_%n participant in call_::_%n participants in call_" : ["Kõnes on %n osaleja","Kõnes on %n osalejat"],
    "Screensharing requires the page to be loaded through HTTPS." : "Ekraanijagamiseks tuleb leht laadida üle HTTPS protokolli.",
    "Grid view" : "Ruudustikvaade",
    "Lower hand" : "Lase käsi alla",
    "Remove participant {name}" : "Eemalda osaleja {name}",
    "Submit" : "Saada",
    "Search …" : "Otsi…",
    "Mention myself" : "Maini iseennast",
    "Talk conversation" : "Talk suhtlus",
    "User" : "Kasutaja",
    "User name or email address" : "Kasutaja nimi või e-posti aadress",
    "Password" : "Parool",
    "API token" : "API kood",
    "Login" : "Logi sisse",
    "Nickname" : "Hüüdnimi",
    "Client ID" : "Kliendi ID",
    "Media" : "Meedia",
    "Polls" : "Küsitlused",
    "Locations" : "Asukohad",
    "Audio" : "Helid",
    "Other" : "Muu",
    "Group" : "Grupp",
    "Team" : "Tiim",
    "You added {user0} and {user1}" : "Sina lisasid kasutajad {user0} ja {user1}",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["Sina lisasid kasutajad {user0}, {user1} ning veel %n osaleja","Sina lisasid kasutajad {user0}, {user1} ning veel %n osalejat"],
    "An administrator added you and {user0}" : "Peakasutaja lisas sinu ja kasutaja {user0}",
    "{actor} added you and {user0}" : "{actor} lisas sinu ja kasutaja {user0}",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["Peakasutaja lisas sinu, {user0} ja veel %n kasutaja","Peakasutaja lisas sinu, {user0} ja veel %n kasutajat"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} lisas sinu, {user0} ja veel %n kasutaja","{actor} lisas sinu, {user0} ja veel %n kasutajat"],
    "You removed {user0} and {user1}" : "Sina eemaldasid osalejad {user0} ja {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["Sina eemaldasid kasutajad {user0}, {user1} ning veel %n osaleja","Sina eemaldasid kasutajad {user0}, {user1} ning veel %n osalejat"],
    "An administrator removed you and {user0}" : "Peakasutaja eemaldas sinu ja kasutaja {user0}",
    "{actor} removed you and {user0}" : "{actor} eemaldas sinu ja kasutaja {user0}",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["Peakasutaja eemaldas sinu, {user0} ja veel %n kasutaja","Peakasutaja eemaldas sinu, {user0} ja veel %n kasutajat"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} eemaldas sinu, {user0} ja veel %n kasutaja","{actor} eemaldas sinu, {user0} ja veel %n kasutajat"],
    "An administrator removed {user0} and {user1}" : "Peakasutaja eemaldas kasutajad {user0} ja {user1} ",
    "{actor} removed {user0} and {user1}" : "{actor} eemaldas osalejad {user0} ja {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["Peakasutaja eemaldas osalejad {user0} ja {user1} ning veel %n osaleja","Peakasutaja eemaldas osalejad {user0} ja {user1} ning veel %n osalejat"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} eemaldas osalejad {user0} ja {user1} ning veel %n osaleja","{actor} eemaldas osalejad {user0} ja {user1} ning veel %n osalejat"],
    "You promoted {user0} and {user1} to moderators" : "Sina määrasid kasutajad {user0} ja {user1} moderaatoriteks",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["Sina määrasid kasutajad {user0}, {user1} ning veel %n osaleja moderaatoriteks","Sina määrasid kasutajad {user0}, {user1} ning veel %n osalejat moderaatoriteks"],
    "An administrator promoted you and {user0} to moderators" : "Peakasutaja määras sinu ja kasutaja {user0} moderaatoriteks",
    "{actor} promoted you and {user0} to moderators" : "{actor} määras sinu ja kasutaja {user0} moderaatoriteks",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["Peakasutaja määras sinu, {user0} ja veel %n kasutaja moderaatoriteks","Peakasutaja määras sinu, {user0} ja veel %n kasutajat moderaatoriteks"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} määras sinu, {user0} ja veel %n kasutaja moderaatoriteks","{actor} määras sinu, {user0} ja veel %n kasutajat moderaatoriteks"],
    "An administrator promoted {user0} and {user1} to moderators" : "Peakasutaja määras kasutajad {user0} ja {user1} moderaatoriteks",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} määras kasutajad {user0} ja {user1} moderaatoriteks",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["Peakasutaja määras kasutajad {user0} ja {user1} ning veel %n kasutaja moderaatoriteks","Peakasutaja määras kasutajad {user0} ja {user1} ning veel %n kasutajat moderaatoriteks"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} määras kasutajad {user0}, {user1} ja veel %n kasutaja moderaatoriteks","{actor} määras kasutajad {user0}, {user1} ja veel %n kasutajat moderaatoriteks"],
    "You:" : "Sina:",
    "{actor}:" : "{actor}:",
    "Nextcloud Talk was updated." : "Nextcloud Talk on uuendatud.",
    "(edited)" : "(muudetud)",
    "(edited by you)" : "(muudetud sinu poolt)",
    "(edited by a deleted user)" : "(muudetud kustutatud kasutaja poolt)",
    "(edited by {moderator})" : "(muudetud {moderator} moderaatori poolt)",
    "In conversation" : "Vestluses",
    "Search in conversation: {conversation}" : "Otsi vestlusest: {conversation}",
    "Error while clearing conversation history" : "Viga vestluse ajaloo kustutamisel",
    "Error occurred while allowing guests" : "Külaliste lubamisel tekkis viga",
    "Error occurred while disallowing guests" : "Külaliste keelamisel tekkis viga",
    "Conversation password has been saved" : "Vestluse salasõna on salvestatud",
    "Conversation password has been removed" : "Vestluse salasõna on eemaldatud",
    "Error occurred while saving conversation password" : "Vestluse salasõna salvestamisel tekkis viga",
    "Call recording is starting." : "Kõne salvestamine algab.",
    "Call recording stopped while starting." : "Kõne salvestamine peatus alustamisel.",
    "Call recording stopped. You will be notified once the recording is available." : "Kõne salvestamine on lõppenud. Sa saad teate, kui salvestis on saadaval.",
    "Conversation picture set" : "Vestluse pilt on salvestatud",
    "Conversation picture deleted" : "Vestluse pilt on kustutatud",
    "Could not delete the conversation picture" : "Vestluse pildi kustutamine ei õnnestunud",
    "Error while sharing file" : "Viga faili jagamisel",
    "Failed to join the conversation." : "Vestlusega ei õnnestunud liituda.",
    "{guest} (guest)" : "{guest} (külaline)",
    "Failed to remove reaction" : "Regeerimise eemaldamine ei õnnestunud",
    "Nextcloud is in maintenance mode." : "Nextcloud on hooldusrežiimis.",
    "Nextcloud Talk Federation was updated." : "Nextcloud Talk liitpilves on uuendatud.",
    "Lost connection to signaling server. Trying to reconnect." : "Kadus ühendus kõnehõlbustusserveriga. Proovi, kas ühenduse uuesti loomine aitab.",
    "Lost connection to signaling server." : "Kadus ühendus kõnehõlbustusserveriga.",
    "Please restart the app." : "Palun käivita rakendus uuesti.",
    "Please reload the page." : "Palun laadi leht uuesti.",
    "Please try to restart the app." : "Palun proovi rakenduse uuesti käivtamist.",
    "Please try to reload the page." : "Palun proovi lehe uuesti laadimist.",
    "Do not disturb" : "Ära sega",
    "Away" : "Eemal",
    "Default" : "Vaikeväärtus",
    "Microphone {number}" : "Mikrofon {number}",
    "Camera {number}" : "Kaamera {number}",
    "Speaker {number}" : "Kõlar {number}",
    "The password is wrong. Try again." : "Parool on vale. Proovi uuesti.",
    "Android app" : "Androidi rakendus",
    "iOS app" : "iOS-i rakendus",
    "__language_name__" : "Eesti",
    "Call summary (%s)" : "Kõne kokkuvõte (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "See robot postitab kõne lõppedes kõikidele kõnes osalejatele ülevaatliku sõnumi, osalejate ja ülesannete andmetega",
    "Tasks" : "Ülesanded",
    "Notes" : "Märkmed",
    "Reports" : "Aruanded",
    "Decisions" : "Otsused",
    "Agenda" : "Päevakava",
    "Call summary" : "Kõne kokkuvõte",
    "Call summary - {title}" : "Kõne kokkuvõte - {title}",
    "Copy conversation link" : "Kopeeri vestluse link",
    "Close" : "Sulge",
    "Lost connection to signaling server. Try to reload the page manually." : "Kadus ühendus kõnehõlbustusserveriga. Proovi, kas lehe uuesti laadimine aitab.",
    "Invite all users and emails" : "Kutsu kõiki kasutajaid ja e-posti aadresse"
},
"nplurals=2; plural=(n != 1);");
